#[debug_handler]👎Deprecated since 0.3.3:
Use the axum-macros crate instead
Generates better error messages when applied to a handler function.
Note this crate is deprecated. Use axum-macros instead.
#[debug_handler]Use the axum-macros crate instead
Generates better error messages when applied to a handler function.
Note this crate is deprecated. Use axum-macros instead.